@@ -6,14 +6,10 @@ use vars qw($VERSION @colNames);
 
 use base qw(DBD::Sys::Table);
 
-$VERSION  = "0.101";
+$VERSION  = "0.102";
 @colNames = qw(username id line pid type host timestamp);
 
-my $haveSysUtmp = 0;
-eval {
-    require Sys::Utmp;
-    $haveSysUtmp = 1;
-};
+my $haveSysUtmp;
 
 =pod
 
@@ -74,23 +70,23 @@ The time in epoch seconds which the record was created.
 
 =head1 METHODS
 
-=head2 getTableName
+=head2 get_table_name
 
 Returns 'logins'.
 
 =cut
 
-sub getTableName() { return 'logins'; }
+sub get_table_name() { return 'logins'; }
 
-=head2 getColNames
+=head2 get_col_names
 
 Returns the column names of the table as named in L</Columns>
 
 =cut
 
-sub getColNames() { @colNames }
+sub get_col_names() { @colNames }
 
-=head2 getAttributes
+=head2 get_attributes
 
 Return the attributes supported by this module:
 
@@ -103,27 +99,36 @@ and will use C<_PATH_UTMP>.
 
 =cut
 
-sub getAttributes() { return qw(filename) }
+sub get_attributes() { return qw(filename) }
 
-=head2 getPrimaryKey
+=head2 get_primary_key
 
 Returns 'timestamp' - you must be very quick to login twice per second
 
 =cut
 
-sub getPrimaryKey() { return 'timestamp'; }
+sub get_primary_key() { return 'timestamp'; }
 
-=head2 collectData
+=head2 collect_data
 
 Retrieves the data from the utmp database and put it into fetchable rows.
 
 =cut
 
-sub collectData()
+sub collect_data()
 {
     my $self = $_[0];
     my @data;
 
+    unless ( defined($haveSysUtmp) )
+    {
+        $haveSysUtmp = 0;
+        eval {
+            require Sys::Utmp;
+            $haveSysUtmp = 1;
+        };
+    }
+
     if ($haveSysUtmp)
     {
         my %params;
