@@ -11,7 +11,7 @@ eval {
     $haveWin32pwent = 1;
 };
 
-$VERSION  = "0.101";
+$VERSION  = "0.102";
 @colNames = qw(groupname grpass gid members);
 
 =pod
@@ -51,29 +51,29 @@ Numerical count of the members in this group
 
 =head1 METHODS
 
-=head2 getTableName
+=head2 get_table_name
 
 Returns 'grent'.
 
 =cut
 
-sub getTableName() { return 'grent'; }
+sub get_table_name() { return 'grent'; }
 
-=head2 getColNames
+=head2 get_col_names
 
 Returns the column names of the table as named in L</Columns>
 
 =cut
 
-sub getColNames() { @colNames }
+sub get_col_names() { @colNames }
 
-=head2 collectData
+=head2 collect_data
 
 Retrieves the data from the group database and put it into fetchable rows.
 
 =cut
 
-sub collectData()
+sub collect_data()
 {
     my @data;
 
